# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['newrelic',
 'newrelic.alert',
 'newrelic.cli',
 'newrelic.nerdgraph',
 'newrelic.nerdgraph.alert',
 'newrelic.nerdgraph.synthetic',
 'newrelic.synthetic',
 'newrelic.utils']

package_data = \
{'': ['*']}

install_requires = \
['loguru>=0.6.0,<0.7.0', 'requests>=2.28.1,<3.0.0']

entry_points = \
{'console_scripts': ['newrelic = newrelic.cli.entrypoint:main']}

setup_kwargs = {
    'name': 'newrelic-synthetic-python-client',
    'version': '0.3.0',
    'description': 'NewRelic CLI',
    'long_description': '# newrelic-synthetic-python-client\nPython lib to interact with New Relic Synthetic Monitors API using NerdGraph\n\n- [newrelic-synthetic-python-client](#newrelic-synthetic-python-client)\n- [Installation](#installation)\n  - [Requirements](#requirements)\n  - [Install with pip](#install-with-pip)\n  - [Development](#development)\n- [Usage Example](#usage-example)\n  - [Configuration file](#configuration-file)\n    - [Configuration file places](#configuration-file-places)\n  - [Log level](#log-level)\n  - [Secure Credential](#secure-credential)\n    - [List secure credentials](#list-secure-credentials)\n    - [Update or Create secure credentials](#update-or-create-secure-credentials)\n  - [Scripted Browser Monitors](#scripted-browser-monitors)\n    - [List scripted browser monitors](#list-scripted-browser-monitors)\n    - [Update or Create scripted browser monitor](#update-or-create-scripted-browser-monitor)\n    - [Update scripted browser monitor with account](#update-scripted-browser-monitor-with-account)\n  - [CRUD Alert Policy](#crud-alert-policy)\n    - [Create Alert Policy](#create-alert-policy)\n    - [List Alert Policy](#list-alert-policy)\n    - [Update Alert Policy](#update-alert-policy)\n    - [Delete Alert Policy](#delete-alert-policy)\n  - [CRUD Alert condition](#crud-alert-condition)\n    - [Create Alert Condition](#create-alert-condition)\n    - [List Alert Condition](#list-alert-condition)\n    - [Update Alert Condition](#update-alert-condition)\n    - [Delete Alert Condition](#delete-alert-condition)\n  - [CRUD Alert Destinations](#crud-alert-destinations)\n    - [Create Alert Destinations](#create-alert-destinations)\n    - [List Alert Destinations](#list-alert-destinations)\n    - [Update Alert Destinations](#update-alert-destinations)\n    - [Delete Alert Destinations](#delete-alert-destinations)\n  - [CRUD Alert Channels](#crud-alert-channels)\n    - [Create Alert Channels](#create-alert-channels)\n    - [List Alert Channels](#list-alert-channels)\n    - [Update Alert Channels](#update-alert-channels)\n    - [Delete Alert Channels](#delete-alert-channels)\n  - [CRUD Alert Workflows](#crud-alert-workflows)\n    - [Create Alert Workflows](#create-alert-workflows)\n    - [List Alert Workflows](#list-alert-workflows)\n    - [Update Alert Workflows](#update-alert-workflows)\n    - [Delete Alert Workflows](#delete-alert-workflows)\n  - [Service Level](#service-level)\n    - [Create Synthetic Service Level](#create-synthetic-service-level)\n    - [List Synthetic Service Level](#list-synthetic-service-level)\n    - [Update Synthetic Service Level](#update-synthetic-service-level)\n\n# Installation\n\n## Requirements\n- Python 3.8 +\n- Poetry\n\n## Install with pip\n\n\n```\npip install newrelic-synthetic-python-client\n```\n\n\n## Development\n\n```\npython3 -m venv .venv\nsource ./venv/bin/activate\n```\n\nVerify the poetry is using the virutalenv\n```\npoetry env info\n\nVirtualenv\nPython:         3.8.13\nImplementation: CPython\nPath:           /Users/the/path/of/newrelic-synthetic-python-client/.venv\nValid:          True\n\nSystem\nPlatform: darwin\nOS:       posix\nPython:   /opt/homebrew/opt/python@3.8/bin/../Frameworks/Python.framework/Versions/3.8\n```\n\nInstall the dependencies\n\n```\npoetry install\n```\n\nThis will install all the dev/non-dev dependencies.\n\n# Usage Example\n\n## Configuration file\n\nThe configuration file contains the information to interact with NewRelic API endpoint, either via RESTFul API or Graphql.\n\nCreate a JSON file contains the API Key, the example is like the following\n```json\n{\n    "endpoint": "https://api.newrelic.com/graphql",\n    "api_key": "<user_api_key>",\n    "account_id": "<numeric_account_id>"\n}\n```\nLet\'s say the file is located at `$HOME/my-account.json`. To use this file, you need to specify it in the environment variable `NEWRELIC_PYTHON_CLIENT_JSON`\n```\nexport NEWRELIC_PYTHON_CLIENT_JSON=.config/wats-ng-dev.json \n```\n\n### Configuration file places\n\nSearch order\n1. `$HOME/.newrelic-python-client.json`\n2. `$HOME/.config/newrelic-python-client.json`\n3. `$CWD/newrelic-python-client.json`\n4. Specified by environment `$NEWRELIC_PYTHON_CLIENT_JSON`\n\nThe one with larger number will overwrite the one with smaller number.\n\n1. You can put the JSON configuration file to `$HOME/.newrelic-python-client.json` and the configuration will take effect.\n2. And then you add a new file in `$HOME/.config/newrelic-python-client.json`, and this one will take effect, `$HOME/.newrelic-python-client.json` will no longer take effect.\n3. Then you add a new file in `$CWD/newrelic-python-client.json`, then only this one will take effect.\n4. And finally, if you specify the file by environment variable, the environment variable become the only one that take effect.\n\n## Log level\n\nThe default log level is set to "INFO". You can change it by updating the environment variable `NR_LOG_LEVEL`.\n\nThe possible log levels are\n- TRACE\n- DEBUG\n- INFO\n- WARNING\n- ERROR\n\nThe full list can be found in [loguru document](https://loguru.readthedocs.io/en/stable/api/logger.html) the "The severity levels" section.\n\nThe following command set the log level to TRACE and run the script.\n```\nNR_LOG_LEVEL="TRACE" python src/newrelic.py synthetic secure_credential put --key SPS_ID_TOKEN --value 123  \n```\n\n\n## Secure Credential\n### List secure credentials\n```\npython src/newrelic.py synthetic secure_credential list\n```\n\n### Update or Create secure credentials\n\n```\npython src/newrelic.py synthetic secure_credential put --key SPS_ID_TOKEN --value 123\n```\nIf the key `SPS_ID_TOKEN` already exist in your secure credentials storage, this command will update the existing credential. If the key does not exist, this command will create a new credential.\n\n## Scripted Browser Monitors\n\n### List scripted browser monitors\n\n```\nNR_LOG_LEVEL="TRACE" python src/newrelic.py synthetic scripted_browser list\n```\n\n### Update or Create scripted browser monitor\n\n```\nNR_LOG_LEVEL="INFO" python src/newrelic.py synthetic scripted_browser put --monitor-name "AUTO CREATE" \n```\n\n### Update scripted browser monitor with account\n\n```sh\npython src/newrelic.py synthetic scripted_browser put --monitor-name "You Scripted Monitor Name"  --script-content "You Script Path" --script-content "You Script Path"\n```\n\n\n## CRUD Alert Policy\n\n### Create Alert Policy\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert policy add --name \'policy name\' --preference="PER_CONDITION"\n```\n\n### List Alert Policy\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert policy list\n```\n\n### Update Alert Policy\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert policy update --name "policy name" --preference "PER_POLICY" --policy-id "3715372"\n```\n\n### Delete Alert Policy\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert policy delete --policy-id "3715372"\n```\n\n## CRUD Alert condition\n\n### Create Alert Condition\n```sh\n# Threshold Type Static\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert condition add  --name "auto_add_1" --policy-id "3719613"\n\n# Threshold Type Baseline\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert condition add  --name "auto_add_baseline" --policy-id "3717302" --type "baseline" --operator "ABOVE" --threshold "1" --threshold-duration "120"\n```\n\n### List Alert Condition\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert condition list\n```\n\n### Update Alert Condition\n```sh\n# Threshold Type Static \nNR_LOG_LEVEL="INFO" python src/newrelic.py alert condition update --condition-id "28613358" --name "auto_static_update"\n\n# Threshold Type Baseline\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert condition update  --name "auto_add_baseline_update" --condition-id "28614376" --type "baseline" --operator "ABOVE" --threshold "1" --threshold-duration "120"\n```\n\n### Delete Alert Condition\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert condition delete --condition-id "28613141"\n```\n\n## CRUD Alert Destinations\n\n### Create Alert Destinations\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert destinations add --name "auto_add_1" --email "test@example.com" \n```\n\n### List Alert Destinations\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert destinations list\n```\n\n### Update Alert Destinations\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert destinations update --name "auto_add_update" --destinations-id "You-Destination-ID"\n```\n\n### Delete Alert Destinations\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert destinations delete --destinations-id "You-Destination-ID"\n```\n\n## CRUD Alert Channels\n\n### Create Alert Channels\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert channels add --name "auto_channel_1" --destination-id "You-Destination-ID"\n```\n\n### List Alert Channels\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert channels list\n```\n\n### Update Alert Channels\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert channels update --name "auto_channel_update_1" --channel-id "You-Channel-ID"\n```\n\n### Delete Alert Channels\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert channels delete  --channel-id  "You-Channel-ID"\n```\n\n## CRUD Alert Workflows\n\n### Create Alert Workflows\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert workflows add --name "auto_workflow_add_1" --policy-id "You-Policy-ID" --channel-id  "You-Channel-ID"\n```\n\n### List Alert Workflows\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert workflows list --type "EMAIL"\n```\n\n### Update Alert Workflows\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert workflows update --name "auto_workflow_update_1" --workflow-id "You-Workflow-ID"\n```\n\n### Delete Alert Workflows\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py alert workflows delete  --workflow-id  "You-Workflow-ID"\n```\n\n## Service Level\n\n### Create Synthetic Service Level\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py synthetic service_level add --monitor-name "You-monitor-name" --name "You-service-level-name"\n```\n\n### List Synthetic Service Level\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py synthetic service_level list --monitor-name "You-monitor-name"\n```\n\n### Update Synthetic Service Level\n\n```sh\nNR_LOG_LEVEL="INFO" python src/newrelic.py synthetic service_level update --indicators-id "You-indicators-id" --count "1"\n```\n',
    'author': 'Junkai Zhang',
    'author_email': 'drink3y@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Drinkey/newrelic-synthetic-python-client',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
